@@ -1,17 +1,19 @@
 from django.urls import include, path, reverse
 from django.utils.html import format_html
-from django.utils.translation import gettext
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import ngettext
 from wagtail.admin.menu import MenuItem
 from wagtail.admin.search import SearchArea
 
 # from wagtail.admin.site_summary import SummaryItem
+from wagtail.admin.admin_url_finder import ModelAdminURLFinder, register_admin_url_finder
 from wagtail.core import hooks
 
 from wagtail_embed_videos import admin_urls, get_embed_video_model
 from wagtail_embed_videos.forms import GroupEmbedVideoPermissionFormSet
 from wagtail_embed_videos.permissions import permission_policy
+from wagtail_embed_videos.views.bulk_actions import (
+    AddTagsBulkAction, AddToCollectionBulkAction, DeleteBulkAction)
 
 
 @hooks.register("register_admin_urls")
@@ -59,9 +61,9 @@ def editor_js():
 
 # class EmbedVideosSummaryItem(SummaryItem):
 #     order = 201
-#     template = "wagtail_embed_videos/homepage/site_summary_videos.html"
+#     template_name = "wagtail_embed_videos/homepage/site_summary_videos.html"
 
-#     def get_context(self):
+#     def get_context_data(self, parent_context):
 #         return {
 #             "total_videos": get_embed_video_model().objects.count(),
 #         }
@@ -107,3 +109,14 @@ def describe_collection_docs(collection):
             % {"count": embedvideos_count},
             "url": url,
         }
+
+
+class EmbedVideoAdminURLFinder(ModelAdminURLFinder):
+    edit_url_name = 'wagtail_embed_videos:edit'
+    permission_policy = permission_policy
+
+register_admin_url_finder(get_embed_video_model(), EmbedVideoAdminURLFinder)
+
+
+for action_class in [AddTagsBulkAction, AddToCollectionBulkAction, DeleteBulkAction]:
+    hooks.register('register_bulk_action', action_class)
